@@ -10,8 +10,8 @@
 #ifndef liblldb_IRInterpreter_h_
 #define liblldb_IRInterpreter_h_
 
-#include "lldb/Core/ConstString.h"
-#include "lldb/Core/Stream.h"
+#include "lldb/Utility/ConstString.h"
+#include "lldb/Utility/Stream.h"
 #include "lldb/lldb-public.h"
 #include "llvm/ADT/ArrayRef.h"
 #include "llvm/Pass.h"
@@ -39,20 +39,20 @@ class IRMemoryMap;
 class IRInterpreter {
 public:
   static bool CanInterpret(llvm::Module &module, llvm::Function &function,
-                           lldb_private::Error &error,
+                           lldb_private::Status &error,
                            const bool support_function_calls);
 
   static bool Interpret(llvm::Module &module, llvm::Function &function,
                         llvm::ArrayRef<lldb::addr_t> args,
                         lldb_private::IRExecutionUnit &execution_unit,
-                        lldb_private::Error &error,
+                        lldb_private::Status &error,
                         lldb::addr_t stack_frame_bottom,
                         lldb::addr_t stack_frame_top,
                         lldb_private::ExecutionContext &exe_ctx);
 
 private:
   static bool supportsFunction(llvm::Function &llvm_function,
-                               lldb_private::Error &err);
+                               lldb_private::Status &err);
 };
 
 #endif
