@@ -10,14 +10,13 @@
 #ifndef lldb_Host_netbsd_HostInfoNetBSD_h_
 #define lldb_Host_netbsd_HostInfoNetBSD_h_
 
-#include "lldb/Host/FileSpec.h"
 #include "lldb/Host/posix/HostInfoPosix.h"
+#include "lldb/Utility/FileSpec.h"
 
 namespace lldb_private {
 
 class HostInfoNetBSD : public HostInfoPosix {
 public:
-  static uint32_t GetMaxThreadNameLength();
   static bool GetOSVersion(uint32_t &major, uint32_t &minor, uint32_t &update);
   static bool GetOSBuildString(std::string &s);
   static bool GetOSKernelDescription(std::string &s);
