@@ -20,7 +20,7 @@ class ProcessLaunchInfo;
 class ProcessLauncherWindows : public ProcessLauncher {
 public:
   virtual HostProcess LaunchProcess(const ProcessLaunchInfo &launch_info,
-                                    Error &error);
+                                    Status &error);
 
 protected:
   HANDLE GetStdioHandle(const ProcessLaunchInfo &launch_info, int fd);
