@@ -11,9 +11,11 @@
 #define LLDB_lldb_windows_h_
 
 #define NTDDI_VERSION NTDDI_VISTA
+#undef _WIN32_WINNT // undef a previous definition to avoid warning
 #define _WIN32_WINNT _WIN32_WINNT_VISTA
 #define WIN32_LEAN_AND_MEAN
 #define NOGDI
+#undef NOMINMAX // undef a previous definition to avoid warning
 #define NOMINMAX
 #include <windows.h>
 #undef GetUserName
@@ -26,4 +28,4 @@
 #define FAR
 #define NEAR
 
-#endif  // LLDB_lldb_windows_h_
+#endif // LLDB_lldb_windows_h_
