@@ -11,6 +11,9 @@
 #define liblldb_DeclVendor_h_
 
 #include "lldb/Core/ClangForward.h"
+#include "lldb/lldb-defines.h"
+
+#include "clang/AST/ExternalASTMerger.h"
 
 #include <vector>
 
@@ -52,6 +55,15 @@ public:
                              uint32_t max_matches,
                              std::vector<clang::NamedDecl *> &decls) = 0;
 
+  //------------------------------------------------------------------
+  /// Interface for ExternalASTMerger.  Returns an ImporterSource 
+  /// allowing type completion.
+  ///
+  /// @return
+  ///     An ImporterSource for this DeclVendor.
+  //------------------------------------------------------------------
+  virtual clang::ExternalASTMerger::ImporterSource GetImporterSource() = 0;
+
 private:
   //------------------------------------------------------------------
   // For DeclVendor only
