@@ -44,7 +44,7 @@ def setupCrashInfoHook():
             if not os.path.isfile(dylib_dst) or os.path.getmtime(
                     dylib_dst) < os.path.getmtime(dylib_src):
                 # we need to compile
-                cmd = "SDKROOT= xcrun clang %s -o %s -framework Python -Xlinker -dylib -iframework /System/Library/Frameworks/ -Xlinker -F /System/Library/Frameworks/" % (
+                cmd = "SDKROOT= xcrun clang %s -o %s -framework Python -Xlinker -dylib" % (
                     dylib_src, dylib_dst)
                 if subprocess.call(
                         cmd, shell=True) != 0 or not os.path.isfile(dylib_dst):
@@ -66,7 +66,7 @@ categoriesList = None
 # set to true if we are going to use categories for cherry-picking test cases
 useCategories = False
 # Categories we want to skip
-skipCategories = []
+skipCategories = ["darwin-log"]
 # use this to track per-category failures
 failuresPerCategory = {}
 
@@ -76,11 +76,9 @@ lldbFrameworkPath = None
 # Test suite repeat count.  Can be overwritten with '-# count'.
 count = 1
 
-# The 'archs' and 'compilers' can be specified via command line.  The corresponding
-# options can be specified more than once. For example, "-A x86_64 -A i386"
-# => archs=['x86_64', 'i386'] and "-C gcc -C clang" => compilers=['gcc', 'clang'].
-archs = None        # Must be initialized after option parsing
-compilers = None    # Must be initialized after option parsing
+# The 'arch' and 'compiler' can be specified via command line.
+arch = None        # Must be initialized after option parsing
+compiler = None    # Must be initialized after option parsing
 
 # The arch might dictate some specific CFLAGS to be passed to the toolchain to build
 # the inferior programs.  The global variable cflags_extras provides a hook to do
