@@ -42,7 +42,7 @@ class Radar9673644TestCase(TestBase):
 
         # rdar://problem/9673664 lldb expression evaluation problem
 
-        self.expect('expr char c[] = "foo"; c[0]',
+        self.expect('expr char str[] = "foo"; str[0]',
                     substrs=["'f'"])
         # runCmd: expr char c[] = "foo"; c[0]
         # output: (char) $0 = 'f'
