@@ -57,23 +57,6 @@ class TopLevelExpressionsTestCase(TestBase):
         self.runCmd("run", RUN_SUCCEEDED)
 
     @add_test_categories(['pyapi'])
-    @expectedFailureAndroid(api_levels=[21, 22], bugnumber="llvm.org/pr27787")
-    @expectedFailureAll(
-        oslist=["linux"],
-        archs=[
-            "arm",
-            "aarch64"],
-        bugnumber="llvm.org/pr27787")
-    @expectedFailureAll(
-        bugnumber="llvm.org/pr28353",
-        oslist=["linux"],
-        archs=[
-            "i386",
-            "x86_64"],
-        compiler="gcc",
-        compiler_version=[
-            "<",
-            "4.9"])
     @skipIf(debug_info="gmodules")  # not relevant
     @skipIf(oslist=["windows"])  # Error in record layout on Windows
     def test_top_level_expressions(self):
