@@ -186,16 +186,27 @@ class ObjCDataFormatterTestCase(TestBase):
 
     def nsnumber_data_formatter_commands(self):
         # Now enable AppKit and check we are displaying Cocoa classes correctly
-        self.expect('frame variable num1 num2 num3 num4 num5 num6 num7 num9',
+        self.expect('frame variable num1 num2 num3 num5 num6 num7 num9',
                     substrs=['(NSNumber *) num1 = ', ' (int)5',
                              '(NSNumber *) num2 = ', ' (float)3.1',
                              '(NSNumber *) num3 = ', ' (double)3.14',
-                             '(NSNumber *) num4 = ', ' (long)-2',
                              '(NSNumber *) num5 = ', ' (char)65',
                              '(NSNumber *) num6 = ', ' (long)255',
                              '(NSNumber *) num7 = ', '2000000',
                              '(NSNumber *) num9 = ', ' (short)-31616'])
 
+        
+        self.runCmd('frame variable num4', check=True)
+        output = self.res.GetOutput()
+        i128_handled_correctly = False
+
+        if output.find('long') >= 0:
+            i128_handled_correctly = (output.find('(long)-2') >= 0)
+        if output.find('int128_t') >= 0:
+            i128_handled_correctly = (output.find('(int128_t)18446744073709551614') >= 0) # deliberately broken, should be ..14
+
+        self.assertTrue(i128_handled_correctly, "Expected valid output for int128_t; got " + output)
+
         self.expect('frame variable num_at1 num_at2 num_at3 num_at4',
                     substrs=['(NSNumber *) num_at1 = ', ' (int)12',
                              '(NSNumber *) num_at2 = ', ' (int)-12',
