@@ -19,9 +19,8 @@ class LibcxxListDataFormatterTestCase(TestBase):
 
     mydir = TestBase.compute_mydir(__file__)
 
-    @skipIf(compiler="gcc")
-    @skipIfWindows  # libc++ not ported to Windows yet
-    @add_test_categories(["pyapi"])
+    @add_test_categories(["libc++"])
+    @expectedFailureAndroid(bugnumber="llvm.org/pr32592")
     @skipIfDarwin  # rdar://25499635
     def test_with_run_command(self):
         self.build()
@@ -40,8 +39,6 @@ class LibcxxListDataFormatterTestCase(TestBase):
         # Run the program, it should stop at breakpoint 1.
         process = target.LaunchSimple(
             None, None, self.get_process_working_directory())
-        lldbutil.skip_if_library_missing(
-            self, target, lldbutil.PrintableRegex("libc\+\+"))
         self.assertTrue(process and process.IsValid(), PROCESS_IS_VALID)
         self.assertEqual(
             len(lldbutil.get_threads_stopped_at_breakpoint(process, breakpoint1)), 1)
