@@ -49,7 +49,9 @@ class TlsGlobalTestCase(TestBase):
         """Test thread-local storage."""
         self.build()
         exe = os.path.join(os.getcwd(), "a.out")
-        self.runCmd("file " + exe, CURRENT_EXECUTABLE_SET)
+        target = self.dbg.CreateTarget(exe)
+        if self.platformIsDarwin():
+            self.registerSharedLibrariesWithTarget(target, ['liba.dylib'])
 
         line1 = line_number('main.c', '// thread breakpoint')
         lldbutil.run_break_set_by_file_and_line(
