@@ -13,9 +13,6 @@ from lldbsuite.test import lldbutil
 
 class TestObjCStepping(TestBase):
 
-    def getCategories(self):
-        return ['basic_process']
-
     mydir = TestBase.compute_mydir(__file__)
 
     def setUp(self):
@@ -35,7 +32,7 @@ class TestObjCStepping(TestBase):
             self.main_source, '// Step over nil should stop here.')
 
     @skipUnlessDarwin
-    @add_test_categories(['pyapi'])
+    @add_test_categories(['pyapi', 'basic_process'])
     def test_with_python_api(self):
         """Test stepping through ObjC method dispatch in various forms."""
         self.build()
@@ -162,6 +159,7 @@ class TestObjCStepping(TestBase):
         newClassName = mySource_isa.GetSummary()
 
         if self.TraceOn():
+            print("className is %s, newClassName is %s" % (className, newClassName))
             print(mySource_isa)
 
         self.assertTrue(
