@@ -16,21 +16,19 @@
 // Other libraries and framework includes
 // Project includes
 
-#include "lldb/lldb-types.h"
 #include "lldb/Interpreter/CommandObjectMultiword.h"
+#include "lldb/lldb-types.h"
 
 namespace lldb_private {
-    class CommandObjectLanguage : public CommandObjectMultiword
-    {
-    public:
-        CommandObjectLanguage (CommandInterpreter &interpreter);
-        
-        ~CommandObjectLanguage() override;
-        
-    protected:
-        bool
-        DoExecute (Args& command, CommandReturnObject &result);
-    };
+class CommandObjectLanguage : public CommandObjectMultiword {
+public:
+  CommandObjectLanguage(CommandInterpreter &interpreter);
+
+  ~CommandObjectLanguage() override;
+
+protected:
+  bool DoExecute(Args &command, CommandReturnObject &result);
+};
 } // namespace lldb_private
 
 #endif // liblldb_CommandObjectLanguage_h_
