@@ -1162,75 +1162,6 @@ DebuggerSP Debugger::FindDebuggerWithID(lldb::user_id_t id) {
   return debugger_sp;
 }
 
-#if 0
-static void
-TestPromptFormats (StackFrame *frame)
-{
-    if (frame == nullptr)
-        return;
-
-    StreamString s;
-    const char *prompt_format =         
-    "{addr = '${addr}'\n}"
-    "{addr-file-or-load = '${addr-file-or-load}'\n}"
-    "{current-pc-arrow = '${current-pc-arrow}'\n}"
-    "{process.id = '${process.id}'\n}"
-    "{process.name = '${process.name}'\n}"
-    "{process.file.basename = '${process.file.basename}'\n}"
-    "{process.file.fullpath = '${process.file.fullpath}'\n}"
-    "{thread.id = '${thread.id}'\n}"
-    "{thread.index = '${thread.index}'\n}"
-    "{thread.name = '${thread.name}'\n}"
-    "{thread.queue = '${thread.queue}'\n}"
-    "{thread.stop-reason = '${thread.stop-reason}'\n}"
-    "{target.arch = '${target.arch}'\n}"
-    "{module.file.basename = '${module.file.basename}'\n}"
-    "{module.file.fullpath = '${module.file.fullpath}'\n}"
-    "{file.basename = '${file.basename}'\n}"
-    "{file.fullpath = '${file.fullpath}'\n}"
-    "{frame.index = '${frame.index}'\n}"
-    "{frame.pc = '${frame.pc}'\n}"
-    "{frame.sp = '${frame.sp}'\n}"
-    "{frame.fp = '${frame.fp}'\n}"
-    "{frame.flags = '${frame.flags}'\n}"
-    "{frame.reg.rdi = '${frame.reg.rdi}'\n}"
-    "{frame.reg.rip = '${frame.reg.rip}'\n}"
-    "{frame.reg.rsp = '${frame.reg.rsp}'\n}"
-    "{frame.reg.rbp = '${frame.reg.rbp}'\n}"
-    "{frame.reg.rflags = '${frame.reg.rflags}'\n}"
-    "{frame.reg.xmm0 = '${frame.reg.xmm0}'\n}"
-    "{frame.reg.carp = '${frame.reg.carp}'\n}"
-    "{function.id = '${function.id}'\n}"
-    "{function.changed = '${function.changed}'\n}"
-    "{function.initial-function = '${function.initial-function}'\n}"
-    "{function.name = '${function.name}'\n}"
-    "{function.name-without-args = '${function.name-without-args}'\n}"
-    "{function.name-with-args = '${function.name-with-args}'\n}"
-    "{function.addr-offset = '${function.addr-offset}'\n}"
-    "{function.concrete-only-addr-offset-no-padding = '${function.concrete-only-addr-offset-no-padding}'\n}"
-    "{function.line-offset = '${function.line-offset}'\n}"
-    "{function.pc-offset = '${function.pc-offset}'\n}"
-    "{line.file.basename = '${line.file.basename}'\n}"
-    "{line.file.fullpath = '${line.file.fullpath}'\n}"
-    "{line.number = '${line.number}'\n}"
-    "{line.start-addr = '${line.start-addr}'\n}"
-    "{line.end-addr = '${line.end-addr}'\n}"
-;
-
-    SymbolContext sc (frame->GetSymbolContext(eSymbolContextEverything));
-    ExecutionContext exe_ctx;
-    frame->CalculateExecutionContext(exe_ctx);
-    if (Debugger::FormatPrompt (prompt_format, &sc, &exe_ctx, &sc.line_entry.range.GetBaseAddress(), s))
-    {
-        printf("%s\n", s.GetData());
-    }
-    else
-    {
-        printf ("what we got: %s\n", s.GetData());
-    }
-}
-#endif
-
 bool Debugger::FormatDisassemblerAddress(const FormatEntity::Entry *format,
                                          const SymbolContext *sc,
                                          const SymbolContext *prev_sc,
