@@ -22,43 +22,33 @@ NativeThreadProtocol::NativeThreadProtocol(NativeProcessProtocol &process,
 
 Status NativeThreadProtocol::ReadRegister(uint32_t reg,
                                           RegisterValue &reg_value) {
-  NativeRegisterContextSP register_context_sp = GetRegisterContext();
-  if (!register_context_sp)
-    return Status("no register context");
+  NativeRegisterContext &register_context = GetRegisterContext();
 
   const RegisterInfo *const reg_info =
-      register_context_sp->GetRegisterInfoAtIndex(reg);
+      register_context.GetRegisterInfoAtIndex(reg);
   if (!reg_info)
     return Status("no register info for reg num %" PRIu32, reg);
 
-  return register_context_sp->ReadRegister(reg_info, reg_value);
+  return register_context.ReadRegister(reg_info, reg_value);
   ;
 }
 
 Status NativeThreadProtocol::WriteRegister(uint32_t reg,
                                            const RegisterValue &reg_value) {
-  NativeRegisterContextSP register_context_sp = GetRegisterContext();
-  if (!register_context_sp)
-    return Status("no register context");
+  NativeRegisterContext& register_context = GetRegisterContext();
 
   const RegisterInfo *const reg_info =
-      register_context_sp->GetRegisterInfoAtIndex(reg);
+      register_context.GetRegisterInfoAtIndex(reg);
   if (!reg_info)
     return Status("no register info for reg num %" PRIu32, reg);
 
-  return register_context_sp->WriteRegister(reg_info, reg_value);
+  return register_context.WriteRegister(reg_info, reg_value);
 }
 
 Status NativeThreadProtocol::SaveAllRegisters(lldb::DataBufferSP &data_sp) {
-  NativeRegisterContextSP register_context_sp = GetRegisterContext();
-  if (!register_context_sp)
-    return Status("no register context");
-  return register_context_sp->WriteAllRegisterValues(data_sp);
+  return GetRegisterContext().WriteAllRegisterValues(data_sp);
 }
 
 Status NativeThreadProtocol::RestoreAllRegisters(lldb::DataBufferSP &data_sp) {
-  NativeRegisterContextSP register_context_sp = GetRegisterContext();
-  if (!register_context_sp)
-    return Status("no register context");
-  return register_context_sp->ReadAllRegisterValues(data_sp);
+  return GetRegisterContext().ReadAllRegisterValues(data_sp);
 }
