@@ -9,8 +9,8 @@
 
 #include "lldb/Host/common/UDPSocket.h"
 
-#include "lldb/Core/Log.h"
 #include "lldb/Host/Config.h"
+#include "lldb/Utility/Log.h"
 
 #ifndef LLDB_DISABLE_POSIX
 #include <arpa/inet.h>
@@ -30,65 +30,45 @@ const int kType = SOCK_DGRAM;
 static const char *g_not_supported_error = "Not supported";
 }
 
-UDPSocket::UDPSocket(NativeSocket socket) : Socket(socket, ProtocolUdp, true) {}
+UDPSocket::UDPSocket(NativeSocket socket) : Socket(ProtocolUdp, true, true) {
+  m_socket = socket;
+}
 
-UDPSocket::UDPSocket(bool child_processes_inherit, Error &error)
-    : UDPSocket(
-          CreateSocket(kDomain, kType, 0, child_processes_inherit, error)) {}
+UDPSocket::UDPSocket(bool should_close, bool child_processes_inherit)
+    : Socket(ProtocolUdp, should_close, child_processes_inherit) {}
 
 size_t UDPSocket::Send(const void *buf, const size_t num_bytes) {
   return ::sendto(m_socket, static_cast<const char *>(buf), num_bytes, 0,
-                  m_send_sockaddr, m_send_sockaddr.GetLength());
+                  m_sockaddr, m_sockaddr.GetLength());
 }
 
-Error UDPSocket::Connect(llvm::StringRef name) {
-  return Error("%s", g_not_supported_error);
+Status UDPSocket::Connect(llvm::StringRef name) {
+  return Status("%s", g_not_supported_error);
 }
 
-Error UDPSocket::Listen(llvm::StringRef name, int backlog) {
-  return Error("%s", g_not_supported_error);
+Status UDPSocket::Listen(llvm::StringRef name, int backlog) {
+  return Status("%s", g_not_supported_error);
 }
 
-Error UDPSocket::Accept(llvm::StringRef name, bool child_processes_inherit,
-                        Socket *&socket) {
-  return Error("%s", g_not_supported_error);
+Status UDPSocket::Accept(Socket *&socket) {
+  return Status("%s", g_not_supported_error);
 }
 
-Error UDPSocket::Connect(llvm::StringRef name, bool child_processes_inherit,
-                         Socket *&send_socket, Socket *&recv_socket) {
-  std::unique_ptr<UDPSocket> final_send_socket;
-  std::unique_ptr<UDPSocket> final_recv_socket;
+Status UDPSocket::Connect(llvm::StringRef name, bool child_processes_inherit,
+                          Socket *&socket) {
+  std::unique_ptr<UDPSocket> final_socket;
 
   Log *log(lldb_private::GetLogIfAnyCategoriesSet(LIBLLDB_LOG_CONNECTION));
   if (log)
     log->Printf("UDPSocket::%s (host/port = %s)", __FUNCTION__, name.data());
 
-  Error error;
+  Status error;
   std::string host_str;
   std::string port_str;
   int32_t port = INT32_MIN;
   if (!DecodeHostAndPort(name, host_str, port_str, port, &error))
     return error;
 
-  // Setup the receiving end of the UDP connection on this localhost
-  // on port zero. After we bind to port zero we can read the port.
-  final_recv_socket.reset(new UDPSocket(child_processes_inherit, error));
-  if (error.Success()) {
-    // Socket was created, now lets bind to the requested port
-    SocketAddress addr;
-    addr.SetToAnyAddress(AF_INET, 0);
-
-    if (::bind(final_recv_socket->GetNativeSocket(), addr, addr.GetLength()) ==
-        -1) {
-      // Bind failed...
-      SetLastError(error);
-    }
-  }
-
-  assert(error.Fail() == !(final_recv_socket && final_recv_socket->IsValid()));
-  if (error.Fail())
-    return error;
-
   // At this point we have setup the receive port, now we need to
   // setup the UDP send socket
 
@@ -118,8 +98,8 @@ Error UDPSocket::Connect(llvm::StringRef name, bool child_processes_inherit,
         service_info_ptr->ai_family, service_info_ptr->ai_socktype,
         service_info_ptr->ai_protocol, child_processes_inherit, error);
     if (error.Success()) {
-      final_send_socket.reset(new UDPSocket(send_fd));
-      final_send_socket->m_send_sockaddr = service_info_ptr;
+      final_socket.reset(new UDPSocket(send_fd));
+      final_socket->m_sockaddr = service_info_ptr;
       break;
     } else
       continue;
@@ -127,11 +107,31 @@ Error UDPSocket::Connect(llvm::StringRef name, bool child_processes_inherit,
 
   ::freeaddrinfo(service_info_list);
 
-  if (!final_send_socket)
+  if (!final_socket)
     return error;
 
-  send_socket = final_send_socket.release();
-  recv_socket = final_recv_socket.release();
+  SocketAddress bind_addr;
+
+  // Only bind to the loopback address if we are expecting a connection from
+  // localhost to avoid any firewall issues.
+  const bool bind_addr_success = (host_str == "127.0.0.1" || host_str == "localhost")
+                                     ? bind_addr.SetToLocalhost(kDomain, port)
+                                     : bind_addr.SetToAnyAddress(kDomain, port);
+
+  if (!bind_addr_success) {
+    error.SetErrorString("Failed to get hostspec to bind for");
+    return error;
+  }
+
+  bind_addr.SetPort(0); // Let the source port # be determined dynamically
+
+  err = ::bind(final_socket->GetNativeSocket(), bind_addr, bind_addr.GetLength());
+
+  struct sockaddr_in source_info;
+  socklen_t address_len = sizeof (struct sockaddr_in);
+  err = ::getsockname(final_socket->GetNativeSocket(), (struct sockaddr *) &source_info, &address_len);
+
+  socket = final_socket.release();
   error.Clear();
   return error;
 }
