@@ -15,13 +15,9 @@
 #include "clang/AST/Type.h"
 
 #include "lldb/Breakpoint/BreakpointLocation.h"
-#include "lldb/Core/ConstString.h"
-#include "lldb/Core/Error.h"
-#include "lldb/Core/Log.h"
 #include "lldb/Core/Module.h"
 #include "lldb/Core/PluginManager.h"
 #include "lldb/Core/Scalar.h"
-#include "lldb/Core/StreamString.h"
 #include "lldb/Expression/FunctionCaller.h"
 #include "lldb/Expression/UtilityFunction.h"
 #include "lldb/Symbol/ClangASTContext.h"
@@ -31,6 +27,10 @@
 #include "lldb/Target/RegisterContext.h"
 #include "lldb/Target/Target.h"
 #include "lldb/Target/Thread.h"
+#include "lldb/Utility/ConstString.h"
+#include "lldb/Utility/Log.h"
+#include "lldb/Utility/Status.h"
+#include "lldb/Utility/StreamString.h"
 
 #include <vector>
 
@@ -127,7 +127,7 @@ struct BufStruct {
 UtilityFunction *AppleObjCRuntimeV1::CreateObjectChecker(const char *name) {
   std::unique_ptr<BufStruct> buf(new BufStruct);
 
-  assert(snprintf(&buf->contents[0], sizeof(buf->contents),
+  int strformatsize = snprintf(&buf->contents[0], sizeof(buf->contents),
                   "struct __objc_class                                         "
                   "           \n"
                   "{                                                           "
@@ -169,9 +169,11 @@ UtilityFunction *AppleObjCRuntimeV1::CreateObjectChecker(const char *name) {
                   "           \n"
                   "}                                                           "
                   "           \n",
-                  name) < (int)sizeof(buf->contents));
+                  name);
+  assert(strformatsize < (int)sizeof(buf->contents));
+  (void)strformatsize;
 
-  Error error;
+  Status error;
   return GetTargetRef().GetUtilityFunctionForLanguage(
       buf->contents, eLanguageTypeObjC, name, error);
 }
@@ -195,7 +197,7 @@ void AppleObjCRuntimeV1::ClassDescriptorV1::Initialize(
 
   m_valid = true;
 
-  Error error;
+  Status error;
 
   m_isa = process_sp->ReadPointerFromMemory(isa, error);
 
@@ -301,7 +303,7 @@ lldb::addr_t AppleObjCRuntimeV1::GetISAHashTablePointer() {
             symbol->GetAddressRef().GetLoadAddress(&process->GetTarget());
 
         if (objc_debug_class_hash_addr != LLDB_INVALID_ADDRESS) {
-          Error error;
+          Status error;
           lldb::addr_t objc_debug_class_hash_ptr =
               process->ReadPointerFromMemory(objc_debug_class_hash_addr, error);
           if (objc_debug_class_hash_ptr != 0 &&
@@ -347,7 +349,7 @@ void AppleObjCRuntimeV1::UpdateISAToDescriptorMapIfNeeded() {
       //     const void *info;
       // } NXHashTable;
 
-      Error error;
+      Status error;
       DataBufferHeap buffer(1024, 0);
       if (process->ReadMemory(hash_table_ptr, buffer.GetBytes(), 20, error) ==
           20) {
