@@ -10,10 +10,9 @@
 #ifndef lldb_RegisterInfoInterface_h
 #define lldb_RegisterInfoInterface_h
 
-#include <vector>
-
-#include "lldb/Core/ArchSpec.h"
+#include "lldb/Utility/ArchSpec.h"
 #include "lldb/lldb-private-types.h"
+#include <vector>
 
 namespace lldb_private {
 
