@@ -14,8 +14,7 @@
 // Project includes
 #include "MinidumpTypes.h"
 
-// Other libraries and framework includes
-#include "lldb/Core/ArchSpec.h"
+#include "lldb/Utility/ArchSpec.h"
 #include "lldb/Utility/DataBuffer.h"
 #include "lldb/Utility/Status.h"
 
