@@ -12,7 +12,7 @@
 #include "DWARFDebugMacinfoEntry.h"
 #include "SymbolFileDWARF.h"
 
-#include "lldb/Core/Stream.h"
+#include "lldb/Utility/Stream.h"
 
 using namespace lldb_private;
 using namespace std;
