@@ -33,6 +33,9 @@ public:
   lldb_private::DWARFExpression::LocationListFormat
   GetLocationListFormat() const override;
 
+  size_t GetObjCMethodDIEOffsets(lldb_private::ConstString class_name,
+                                 DIEArray &method_die_offsets) override;
+
   lldb_private::TypeSystem *
   GetTypeSystemForLanguage(lldb::LanguageType language) override;
 
@@ -45,6 +48,8 @@ public:
     return nullptr;
   }
 
+  DWARFCompileUnit *GetBaseCompileUnit() override;
+
 protected:
   void LoadSectionData(lldb::SectionType sect_type,
                        lldb_private::DWARFDataExtractor &data) override;
@@ -62,6 +67,10 @@ protected:
   lldb::TypeSP FindDefinitionTypeForDWARFDeclContext(
       const DWARFDeclContext &die_decl_ctx) override;
 
+  lldb::TypeSP FindCompleteObjCDefinitionTypeForDIE(
+      const DWARFDIE &die, const lldb_private::ConstString &type_name,
+      bool must_be_implementation) override;
+
   SymbolFileDWARF *GetBaseSymbolFile();
 
   lldb::ObjectFileSP m_obj_file_sp;
