@@ -19,8 +19,8 @@
 
 // Other libraries and framework includes
 // Project includes
-#include "lldb/Core/Error.h"
 #include "lldb/Symbol/CompilerType.h"
+#include "lldb/Utility/Status.h"
 #include "lldb/lldb-public.h"
 
 // This class will insert a UtilityFunction into the inferior process for
@@ -99,7 +99,7 @@ public:
   GetPendingItemsReturnInfo GetPendingItems(Thread &thread, lldb::addr_t queue,
                                             lldb::addr_t page_to_free,
                                             uint64_t page_to_free_size,
-                                            lldb_private::Error &error);
+                                            lldb_private::Status &error);
 
   void Detach();
 
