@@ -425,14 +425,8 @@ Status Variable::GetValuesForVariableExpressionPath(
       llvm::StringRef variable_sub_expr_path =
           variable_expr_path.drop_front(variable_name.size());
       if (!variable_sub_expr_path.empty()) {
-        ValueObject::ExpressionPathScanEndReason reason_to_stop;
-        ValueObject::ExpressionPathEndResultType final_value_type;
-        ValueObject::GetValueForExpressionPathOptions options;
-        ValueObject::ExpressionPathAftermath final_task_on_target;
-
         valobj_sp = variable_valobj_sp->GetValueForExpressionPath(
-            variable_sub_expr_path, &reason_to_stop, &final_value_type, options,
-            &final_task_on_target);
+            variable_sub_expr_path);
         if (!valobj_sp) {
           error.SetErrorStringWithFormat(
               "invalid expression path '%s' for variable '%s'",
