@@ -1089,8 +1089,8 @@ bool StackFrame::GetFrameBaseValue(Scalar &frame_base, Status *error_ptr) {
                 exe_ctx.GetTargetPtr());
 
       if (m_sc.function->GetFrameBaseExpression().Evaluate(
-              &exe_ctx, nullptr, nullptr, nullptr, loclist_base_addr, nullptr,
-              nullptr, expr_value, &m_frame_base_error) == false) {
+              &exe_ctx, nullptr, loclist_base_addr, nullptr, nullptr,
+              expr_value, &m_frame_base_error) == false) {
         // We should really have an error if evaluate returns, but in case
         // we don't, lets set the error to something at least.
         if (m_frame_base_error.Success())
