@@ -9,7 +9,7 @@
 
 #include "gtest/gtest.h"
 
-#include "Helpers/TestUtilities.h"
+#include "TestingSupport/TestUtilities.h"
 #include "lldb/Utility/Status.h"
 #include "lldb/Utility/StreamString.h"
 #include "lldb/Utility/StructuredData.h"
